@@ -4,7 +4,7 @@ from asyncio import TaskGroup
 
 from pytest import RaisesGroup, raises
 
-from utilities.errors import ImpossibleCaseError, repr_error
+from utilities.errors import ImpossibleCaseError, is_instance_error, repr_error
 
 
 class TestImpossibleCaseError:
@@ -14,6 +14,38 @@ class TestImpossibleCaseError:
             raise ImpossibleCaseError(case=[f"{x=}"])
 
 
+class TestIsInstanceError:
+    def test_flat(self) -> None:
+        class CustomError(Exception): ...
+
+        with raises(CustomError) as exc_info:
+            raise CustomError
+
+        assert is_instance_error(exc_info.value, CustomError)
+
+    async def test_group(self) -> None:
+        class CustomError(Exception): ...
+
+        async def coroutine() -> None:
+            raise CustomError
+
+        with RaisesGroup(CustomError) as exc_info:
+            async with TaskGroup() as tg:
+                _ = tg.create_task(coroutine())
+
+        assert is_instance_error(exc_info.value, CustomError)
+
+    def test_false(self) -> None:
+        class Custom1Error(Exception): ...
+
+        class Custom2Error(Exception): ...
+
+        with raises(Custom1Error) as exc_info:
+            raise Custom1Error
+
+        assert not is_instance_error(exc_info.value, Custom2Error)
+
+
 class TestReprError:
     def test_class(self) -> None:
         class CustomError(Exception): ...
