@@ -94,7 +94,6 @@ from utilities.iterables import (
     enumerate_with_edge,
     expanding_window,
     filter_include_and_exclude,
-    group_consecutive_integers,
     groupby_lists,
     hashable_to_iterable,
     is_iterable,
@@ -117,7 +116,6 @@ from utilities.iterables import (
     sum_mappings,
     take,
     transpose,
-    ungroup_consecutive_integers,
     unique_everseen,
 )
 from utilities.sentinel import Sentinel, sentinel
@@ -745,18 +743,6 @@ class TestFilterIncludeAndExclude:
         assert result == expected
 
 
-class TestGroupAndUngroupConsecutiveIntegers:
-    @given(xs=lists(integers(), unique=True).map(sorted))
-    def test_main(self, *, xs: list[int]) -> None:
-        result = list(ungroup_consecutive_integers(group_consecutive_integers(xs)))
-        assert result == xs
-
-    def test_example(self) -> None:
-        result = list(group_consecutive_integers([1, 2, 3, 6, 7, 10, 11, 12]))
-        expected = [(1, 3), (6, 7), (10, 12)]
-        assert result == expected
-
-
 class TestGroupbyLists:
     iterable: ClassVar[str] = "AAAABBBCCDAABB"
 
