@@ -8,20 +8,13 @@ from re import search
 from typing import TYPE_CHECKING, Any, cast
 
 from hypothesis import given
-from hypothesis.strategies import booleans, integers, none, sampled_from
+from hypothesis.strategies import booleans, integers
 from pytest import LogCaptureFixture, mark, param, raises
 
 from tests.conftest import SKIPIF_CI_AND_WINDOWS
-from utilities.hypothesis import (
-    assume_does_not_raise,
-    pairs,
-    temp_paths,
-    text_ascii,
-    zoned_datetimes,
-)
+from utilities.hypothesis import pairs, temp_paths, zoned_date_times
 from utilities.iterables import one
 from utilities.logging import (
-    FilterForKeyError,
     GetLoggingLevelNumberError,
     SizeAndTimeRotatingFileHandler,
     _compute_rollover_actions,
@@ -29,7 +22,6 @@ from utilities.logging import (
     _RotatingLogFile,
     add_filters,
     basic_config,
-    filter_for_key,
     get_format_str,
     get_formatter,
     get_logging_level_number,
@@ -39,7 +31,7 @@ from utilities.logging import (
 from utilities.text import unique_str
 from utilities.types import LogLevel
 from utilities.typing import get_args
-from utilities.whenever import format_compact, get_now, to_local_plain
+from utilities.whenever import get_now, to_local_plain
 
 if TYPE_CHECKING:
     from collections.abc import Mapping
@@ -196,7 +188,7 @@ class TestComputeRolloverActions:
 
         await sleep(1)
         tmp_path.joinpath("log.txt").touch()
-        now = format_compact(to_local_plain(get_now()))
+        now = to_local_plain(get_now())
         tmp_path.joinpath(f"log.99__{now}__{now}.txt").touch()
         actions = _compute_rollover_actions(tmp_path, "log", ".txt")
         assert len(actions.deletions) == 2
@@ -209,33 +201,6 @@ class TestComputeRolloverActions:
         )
 
 
-class TestFilterForKey:
-    @given(key=text_ascii(), value=booleans() | none(), default=booleans())
-    def test_main(self, *, key: str, value: bool | None, default: bool) -> None:
-        logger = getLogger(unique_str())
-        logger.addHandler(handler := StreamHandler(buffer := StringIO()))
-        with assume_does_not_raise(FilterForKeyError):
-            filter_ = filter_for_key(key, default=default)
-        add_filters(handler, filter_)
-        match value:
-            case bool():
-                logger.warning("message", extra={key: value})
-                expected = value
-            case None:
-                logger.warning("message")
-                expected = default
-        result = buffer.getvalue() != ""
-        assert result is expected
-
-    def test_sunder(self) -> None:
-        _ = filter_for_key("_key")
-
-    @given(key=sampled_from(["msg", "__dunder__"]))
-    def test_error(self, *, key: str) -> None:
-        with raises(FilterForKeyError, match="Invalid key: '.*'"):
-            _ = filter_for_key(key)
-
-
 class TestGetFormatStr:
     @mark.parametrize("prefix", [param(">"), param(None)])
     @mark.parametrize("hostname", [param(True), param(False)])
@@ -309,11 +274,11 @@ class TestRotatingLogFile:
         assert result.start is None
         assert result.end is None
 
-    @given(index=integers(min_value=1), end=zoned_datetimes())
+    @given(index=integers(min_value=1), end=zoned_date_times())
     def test_from_path_with_index_and_end(
         self, *, index: int, end: ZonedDateTime
     ) -> None:
-        path = Path(f"log.{index}__{format_compact(to_local_plain(end))}.txt")
+        path = Path(f"log.{index}__{to_local_plain(end)}.txt")
         result = _RotatingLogFile.from_path(path, "log", ".txt")
         assert result is not None
         assert result.stem == "log"
@@ -322,14 +287,14 @@ class TestRotatingLogFile:
         assert result.start is None
         assert result.end == end.round()
 
-    @given(index=integers(min_value=1), datetimes=pairs(zoned_datetimes(), sorted=True))
+    @given(
+        index=integers(min_value=1), datetimes=pairs(zoned_date_times(), sorted=True)
+    )
     def test_from_path_with_index_start_and_end(
         self, *, index: int, datetimes: tuple[ZonedDateTime, ZonedDateTime]
     ) -> None:
         start, end = datetimes
-        path = Path(
-            f"log.{index}__{format_compact(to_local_plain(start))}__{format_compact(to_local_plain(end))}.txt"
-        )
+        path = Path(f"log.{index}__{to_local_plain(start)}__{to_local_plain(end)}.txt")
         result = _RotatingLogFile.from_path(path, "log", ".txt")
         assert result is not None
         assert result.stem == "log"
@@ -352,21 +317,19 @@ class TestRotatingLogFile:
         file = _RotatingLogFile(directory=root, stem="log", suffix=".txt", index=index)
         assert file.path == root.joinpath(f"log.{index}.txt")
 
-    @given(root=temp_paths(), index=integers(min_value=1), end=zoned_datetimes())
+    @given(root=temp_paths(), index=integers(min_value=1), end=zoned_date_times())
     def test_path_with_index_and_end(
         self, *, root: Path, index: int, end: ZonedDateTime
     ) -> None:
         file = _RotatingLogFile(
             directory=root, stem="log", suffix=".txt", index=index, end=end
         )
-        assert file.path == root.joinpath(
-            f"log.{index}__{format_compact(to_local_plain(end))}.txt"
-        )
+        assert file.path == root.joinpath(f"log.{index}__{to_local_plain(end)}.txt")
 
     @given(
         root=temp_paths(),
         index=integers(min_value=1),
-        datetimes=pairs(zoned_datetimes(), sorted=True),
+        datetimes=pairs(zoned_date_times(), sorted=True),
     )
     def test_path_with_index_start_and_end(
         self, *, root: Path, index: int, datetimes: tuple[ZonedDateTime, ZonedDateTime]
@@ -376,7 +339,7 @@ class TestRotatingLogFile:
             directory=root, stem="log", suffix=".txt", index=index, start=start, end=end
         )
         assert file.path == root.joinpath(
-            f"log.{index}__{format_compact(to_local_plain(start))}__{format_compact(to_local_plain(end))}.txt"
+            f"log.{index}__{to_local_plain(start)}__{to_local_plain(end)}.txt"
         )
 
 
@@ -564,12 +527,12 @@ class TestToLogger:
     def test_default(self) -> None:
         assert to_logger().name == "root"
 
-    @given(name=text_ascii(min_size=1))
-    def test_logger(self, *, name: str) -> None:
+    def test_logger(self) -> None:
+        name = unique_str()
         assert to_logger(getLogger(name)).name == name
 
-    @given(name=text_ascii(min_size=1))
-    def test_str(self, *, name: str) -> None:
+    def test_str(self) -> None:
+        name = unique_str()
         assert to_logger(name).name == name
 
     def test_none(self) -> None:
