@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import datetime as dt
 from dataclasses import dataclass
 from pathlib import Path
 from zoneinfo import available_timezones
@@ -9,15 +8,14 @@ from hypothesis import given
 from hypothesis.strategies import sampled_from
 from pytest import mark, param
 
-from utilities.datetime import ZERO_TIME
 from utilities.platform import SYSTEM
-from utilities.types import Duration, Number, PathLike, TDataclass, TimeZone
-from utilities.typing import get_args
+from utilities.types import Dataclass, Number, PathLike, TimeZone
+from utilities.typing import get_literal_elements
 
 
 class TestDataClassProtocol:
     def test_main(self) -> None:
-        def identity(x: TDataclass, /) -> TDataclass:
+        def identity[T: Dataclass](x: T, /) -> T:
             return x
 
         @dataclass(kw_only=True, slots=True)
@@ -27,15 +25,6 @@ class TestDataClassProtocol:
         _ = identity(Example())
 
 
-class TestDuration:
-    @given(x=sampled_from([0, 0.0, ZERO_TIME]))
-    def test_success(self, *, x: Duration) -> None:
-        assert isinstance(x, int | float | dt.timedelta)
-
-    def test_error(self) -> None:
-        assert not isinstance("0", int | float | dt.timedelta)
-
-
 class TestNumber:
     @given(x=sampled_from([0, 0.0]))
     def test_ok(self, *, x: Number) -> None:
@@ -56,7 +45,7 @@ class TestPathLike:
 
 class TestTimeZone:
     def test_main(self) -> None:
-        result = set(get_args(TimeZone))
+        result = set(get_literal_elements(TimeZone))
         expected = available_timezones()
         match SYSTEM:
             case "windows" | "mac":
