@@ -4,11 +4,22 @@ from dataclasses import dataclass, field
 from typing import TYPE_CHECKING, Literal, override
 
 if TYPE_CHECKING:
-    import datetime as dt
     from pathlib import Path
     from uuid import UUID
 
+    import whenever
+    from whenever import (
+        Date,
+        DateDelta,
+        DateTimeDelta,
+        PlainDateTime,
+        Time,
+        TimeDelta,
+        ZonedDateTime,
+    )
+
     from utilities.sentinel import Sentinel
+    from utilities.whenever import DatePeriod, TimePeriod, ZonedDateTimePeriod
 
 
 TrueOrFalseFutureLit = Literal["true", "false"]
@@ -30,7 +41,25 @@ class DataClassFutureCustomEquality:
 
 @dataclass(order=True, unsafe_hash=True, kw_only=True)
 class DataClassFutureDate:
-    date: dt.date
+    date1: Date
+    date2: whenever.Date
+
+
+@dataclass(order=True, unsafe_hash=True, kw_only=True)
+class DataClassFutureDateDelta:
+    delta1: DateDelta
+    delta2: whenever.DateDelta
+
+
+@dataclass(order=True, unsafe_hash=True, kw_only=True)
+class DataClassFutureDatePeriod:
+    period: DatePeriod
+
+
+@dataclass(order=True, unsafe_hash=True, kw_only=True)
+class DataClassFutureDateTimeDelta:
+    delta1: DateTimeDelta
+    delta2: whenever.DateTimeDelta
 
 
 @dataclass(order=True, unsafe_hash=True, kw_only=True)
@@ -142,6 +171,12 @@ class DataClassFuturePath:
     path: Path
 
 
+@dataclass(order=True, unsafe_hash=True, kw_only=True)
+class DataClassFuturePlainDateTime:
+    date_time1: PlainDateTime
+    date_time2: whenever.PlainDateTime
+
+
 @dataclass(order=True, unsafe_hash=True, kw_only=True)
 class DataClassFutureSentinel:
     sentinel: Sentinel
@@ -152,14 +187,27 @@ class DataClassFutureStr:
     str_: str
 
 
+@dataclass(order=True, unsafe_hash=True, kw_only=True)
+class DataClassFutureTime:
+    time1: Time
+    time2: whenever.Time
+
+
 @dataclass(order=True, unsafe_hash=True, kw_only=True)
 class DataClassFutureTimeDelta:
-    timedelta: dt.timedelta
+    delta1: TimeDelta
+    delta2: whenever.TimeDelta
+
+
+@dataclass(order=True, unsafe_hash=True, kw_only=True)
+class DataClassFutureTimePeriod:
+    period: TimePeriod
 
 
 @dataclass(order=True, unsafe_hash=True, kw_only=True)
 class DataClassFutureTimeDeltaNullable:
-    timedelta: dt.timedelta | None = None
+    delta1: TimeDelta | None = None
+    delta2: whenever.TimeDelta | None = None
 
 
 @dataclass(order=True, unsafe_hash=True, kw_only=True)
@@ -175,3 +223,14 @@ class DataClassFutureTypeLiteralNullable:
 @dataclass(order=True, unsafe_hash=True, kw_only=True)
 class DataClassFutureUUID:
     uuid: UUID
+
+
+@dataclass(order=True, unsafe_hash=True, kw_only=True)
+class DataClassFutureZonedDateTime:
+    date_time1: ZonedDateTime
+    date_time2: whenever.ZonedDateTime
+
+
+@dataclass(order=True, unsafe_hash=True, kw_only=True)
+class DataClassFutureZonedDateTimePeriod:
+    period: ZonedDateTimePeriod
