@@ -15,7 +15,7 @@ from hypothesis.strategies import (
 )
 from pytest import raises
 
-from utilities.hypothesis import zoned_datetimes
+from utilities.hypothesis import zoned_date_times
 from utilities.tzdata import HongKong, Tokyo
 from utilities.tzlocal import LOCAL_TIME_ZONE, LOCAL_TIME_ZONE_NAME
 from utilities.zoneinfo import (
@@ -55,7 +55,7 @@ class TestEnsureTimeZone:
         assert result is LOCAL_TIME_ZONE
 
     @given(data=data(), time_zone=timezones())
-    def test_standard_zoned_datetime(
+    def test_standard_zoned_date_time(
         self, *, data: DataObject, time_zone: ZoneInfo
     ) -> None:
         datetime = data.draw(datetimes(timezones=just(time_zone)))
@@ -63,10 +63,10 @@ class TestEnsureTimeZone:
         assert result is time_zone
 
     @given(data=data(), time_zone=timezones())
-    def test_whenever_zoned_datetime(
+    def test_whenever_zoned_date_time(
         self, *, data: DataObject, time_zone: ZoneInfo
     ) -> None:
-        datetime = data.draw(zoned_datetimes(time_zone=time_zone))
+        datetime = data.draw(zoned_date_times(time_zone=time_zone))
         result = ensure_time_zone(datetime)
         assert result is time_zone
 
