@@ -1,10 +1,11 @@
 from __future__ import annotations
 
-from contextlib import contextmanager
 from http.client import HTTPSConnection
 from ipaddress import IPv4Address
 from typing import TYPE_CHECKING
 
+from utilities.contextlib import enhanced_context_manager
+
 if TYPE_CHECKING:
     from collections.abc import Iterator
 
@@ -21,7 +22,7 @@ def get_public_ip(*, timeout: float | None = None) -> IPv4Address:
 ##
 
 
-@contextmanager
+@enhanced_context_manager
 def yield_connection(
     host: str, /, *, timeout: float | None = None
 ) -> Iterator[HTTPSConnection]:
