@@ -23,6 +23,7 @@ from typing import get_type_hints as _get_type_hints
 from uuid import UUID
 from warnings import warn
 
+import whenever
 from whenever import (
     Date,
     DateDelta,
@@ -122,7 +123,6 @@ def get_type_hints(
     warn_name_errors: bool = False,
 ) -> dict[str, Any]:
     """Get the type hints of an object."""
-    result: dict[str, Any] = obj.__annotations__
     _ = {
         Date,
         DateDelta,
@@ -136,10 +136,17 @@ def get_type_hints(
         TimeDelta,
         UUID,
         ZonedDateTime,
-        dt,
+        whenever.Date,
+        whenever.DateDelta,
+        whenever.DateTimeDelta,
+        whenever.PlainDateTime,
+        whenever.Time,
+        whenever.TimeDelta,
+        whenever.ZonedDateTime,
     }
     globalns_use = globals() | ({} if globalns is None else dict(globalns))
     localns_use = {} if localns is None else dict(localns)
+    result: dict[str, Any] = obj.__annotations__
     try:
         hints = _get_type_hints(obj, globalns=globalns_use, localns=localns_use)
     except NameError as error:
