@@ -52,8 +52,6 @@ if TYPE_CHECKING:
         TimeZoneLike,
     )
 
-# type vars
-
 
 # bounds
 
@@ -369,6 +367,14 @@ def get_now_local() -> ZonedDateTime:
 NOW_LOCAL = get_now_local()
 
 
+def get_now_plain(time_zone: TimeZoneLike = UTC, /) -> PlainDateTime:
+    """Get the current zoned datetime."""
+    return get_now(time_zone).to_plain()
+
+
+NOW_PLAIN = get_now_plain()
+
+
 ##
 
 
@@ -1008,9 +1014,14 @@ class _ToHoursNanosecondsError(ToHoursError):
 ##
 
 
-def to_local_plain(date_time: ZonedDateTime, /) -> PlainDateTime:
+def to_local_plain(date_time: ZonedDateTime, /) -> str:
     """Convert a datetime to its local/plain variant."""
-    return date_time.to_tz(LOCAL_TIME_ZONE_NAME).to_plain()
+    return format_compact(date_time.to_tz(LOCAL_TIME_ZONE_NAME).to_plain())
+
+
+def parse_plain_local(text: str, /) -> ZonedDateTime:
+    """Parse a plain, local datetime."""
+    return PlainDateTime.parse_common_iso(text).assume_tz(LOCAL_TIME_ZONE_NAME)
 
 
 ##
@@ -1924,6 +1935,7 @@ __all__ = [
     "MINUTE",
     "MONTH",
     "NOW_LOCAL",
+    "NOW_PLAIN",
     "SECOND",
     "TIME_DELTA_MAX",
     "TIME_DELTA_MIN",
@@ -1963,10 +1975,12 @@ __all__ = [
     "from_timestamp_nanos",
     "get_now",
     "get_now_local",
+    "get_now_plain",
     "get_today",
     "get_today_local",
     "mean_datetime",
     "min_max_date",
+    "parse_plain_local",
     "round_date_or_date_time",
     "sub_year_month",
     "to_date",
